#! /usr/bin/perl
# This script will create the directories and copy the images
# to the images directory of the webserver as configured in
# Portal::Data::Config.  This is a wrapper that calls the
# /usr/lib/pcx_portal/install_app.pl script to do the work.

# install.pl - Created by James Pattie, (james@pcxperience.com)
# Copyright (c) 2000, PC & Web Xperience, Inc. (http://www.pcxperience.com/)
# All rights reserved.  This program is free software; you can redistribute it
# and/or modify it under the same terms as Perl itself.
# 07/02/2001

use Portal::Data::Config;
use strict;
use Portal::Language;
use Portal::Accounting;

$| = 1;

# These are the only customizable variables you need to mess with unless you are doing more work than the portal install_app.pl script is going to do for you.

my $appName = "Accounting";  # make sure this is Uppercase (first letter) at least.
my $configVersion = "0.1";  # The version of your Config.pm config file
my $override = "1";   # 1 = override/backup config file, 0 = don't override config file
my $DBVersion = "$Portal::Accounting::release.$Portal::Accounting::DBVersion";
my $installType = '';  #default to tarball install

print "DBversion: $DBVersion\n";

# end customizable variables

my $prefix = "";
if (defined $ARGV[0])
{
  $prefix = $ARGV[0];
  if (! -d $prefix)
  {
    die "Error!  Prefix directory = '$prefix' does not exist!\n";
  }
}
if (defined $ARGV[1])
{
  $installType = $ARGV[1];
}

my $langObj = Portal::Language->new(lang => 'en');
if ($langObj->didErrorOccur)
{
  die($langObj->errorMessage);
}

my $OUTPUT;
my $configObj = undef;
my $dir;
if ($installType eq '')
{
  eval { $configObj = Portal::Data::Config->new(langObj => $langObj ); };
  #eval { $configObj = Portal::Data::Config->new(langObj => $langObj, prefix => $portal_config_dir ); };
  if ($@)
  {
    die "Error instantiating Portal::Data::Config->new()!  Error = $@\n";
  }
  if ($configObj->didErrorOccur)
  {
    die $configObj->errorMessage;
  }
  $OUTPUT .= "\nInstallation is done.  Goto " . $configObj->httpType . "://" . $configObj->myHostName . $configObj->siteDir . "/ to use the Portal.\n" if (length $prefix == 0);
  $OUTPUT .= "\nDon't forget to re-run setup.pl to finish configuring $appName in the Portal.\n" if (length $prefix > 0);
  $dir = $prefix . $configObj->webRoot . $configObj->siteDir;
}
else #($installType eq 'deb') or rpm? or whatever means we are building a package
{
  $dir = $prefix . "/usr/share/pcx_portal/portal";
}

my $DBdir = "$dir/install/Accounting/db/$DBVersion";
my $DBdir2 = "$dir/install/Accounting/db";
my $ext = "psql";

#update the database file
system("/bin/cat $DBdir/schema-functions.$ext $DBdir/data.$ext $DBdir/system_reports.$ext > $DBdir2/create_db.$ext");

# run the /usr/lib/pcx_portal/install_app.pl script to actually do the work
# The portal must be installed on the machine that you are running this on
# especially if you are building an rpm!

my $INSTALLTYPE;
if ($installType ne '') { $INSTALLTYPE = " --installType $installType "; }
my $location = `pwd`; chomp $location;
print "Running install_app.pl\n";
my $command = "/usr/lib/pcx_portal/install_app.pl $INSTALLTYPE --appname $appName --location $location --override $override --configversion $configVersion" . (length $prefix > 0 ? " --prefix $prefix" : "");
system($command) == 0 or die "Error running install_app.pl from Portal!  Error = $!\n";

# If something else needs to be installed do it now.

print $OUTPUT;
